@@ -4,14 +4,15 @@ from .normalization import (
     ens_cure,
     ens_beautify,
     ens_tokenize,
-    ens_transformations,
+    ens_normalizations,
     is_ens_normalized,
-    DisallowedNameError,
-    DisallowedNameErrorType,
-    CurableError,
-    CurableErrorType,
-    NormalizationTransformation,
-    NormalizationTransformationType,
+    is_ens_normalizable,
+    DisallowedSequence,
+    DisallowedSequenceType,
+    CurableSequence,
+    CurableSequenceType,
+    NormalizableSequence,
+    NormalizableSequenceType,
     TY_VALID,
     TY_MAPPED,
     TY_IGNORED,
